<#ibizinclude>
./CONTROL-BASE.template.ftl
</#ibizinclude>

<#assign import_block>
import echarts from 'echarts';
import 'echarts/map/js/china.js'
</#assign>

<#ibizinclude>
../@MACRO/CONTROL/CONTROL_HEADER-BASE.vue.ftl
</#ibizinclude>

    /**
     * 获取多项数据
     *
     * @returns {any[]}
     * @memberof ${srfclassname('${ctrl.codeName}')}Base
     */
    public getDatas(): any[] {
        return [];
    }

    /**
     * 部件行为--fetch
     *
     * @type {string}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    @Prop() protected fetchAction!: string;

    /**
     * 显示处理提示
     *
     * @type {boolean}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    @Prop({ default: true }) protected showBusyIndicator?: boolean;

    /**
     * 应用状态事件
     *
     * @public
     * @type {(Subscription | undefined)}
     * @memberof ${srfclassname('${ctrl.codeName}')}Base
     */
    public appStateEvent: Subscription | undefined;

    /**
    * 地图数据数组
    *
    * @param {Array<any>}
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public items:Array<any> =[];

    /**
     * 获取单项树
     *
     * @returns {*}
     * @memberof ${srfclassname('${ctrl.codeName}')}Base
     */
    public getData(): any {
        return null;
    }

    /**
    * vue生命周期created
    *
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public created() {
        this.afterCreated();
    }

    /**
     * 执行created后的逻辑
     *
     *  @memberof ${srfclassname('${ctrl.codeName}')}
     */    
    protected afterCreated(){
        if (this.viewState) {
            this.viewStateEvent = this.viewState.subscribe(({ tag, action, data }) => {
                if (!Object.is(this.name, tag)) {
                    return;
                }
                if (Object.is(action, "load")) {
                    this.load(Object.assign(data));
                }
                if (Object.is(action, "search")) {
                    this.load(Object.assign(data));
                }
                if (Object.is(action, "quicksearch")) {
                    this.load(Object.assign({ query: data }));
                }
                if (Object.is(action, "refresh")) {
                    this.refresh();
                }
            });
        }
        if(AppCenterService && AppCenterService.getMessageCenter()){
            this.appStateEvent = AppCenterService.getMessageCenter().subscribe(({ name, action, data }) =>{
                if(!Object.is(name,"MOBMAP")){
                    return;
                }
                if(Object.is(action,'appRefresh')){
                    this.refresh();
                }
            })
        }
    }

    /**
     * 数据加载
     *
     * @private
     * @param {*} [data={}]
     * @param {string} [type=""]
     * @returns {Promise<any>}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    private async load(data: any = {}, type: string = "",isloadding = this.showBusyIndicator): Promise<any> {
        const parentdata: any = {};
        this.$emit('beforeload', parentdata);
        Object.assign(data, parentdata);
        let tempViewParams:any = parentdata.viewparams?parentdata.viewparams:{};
        Object.assign(tempViewParams,JSON.parse(JSON.stringify(this.viewparams)));
        Object.assign(data,{viewparams:tempViewParams});
        const response: any = await this.service.search(this.fetchAction, this.context, data, isloadding);
        if (!response || response.status !== 200) {
            this.$notify({ type: 'danger', message: response.error.message });
            return response;
        }
        this.$emit('load', (response.data && response.data.records) ? response.data.records : []);
        this.items = [];
        this.items = response.data.records;
        return response;
    }

    /**
     * 刷新数据
     *
     * @returns {Promise<any>}
     * @memberof ${srfclassname('${ctrl.name}')}
     */
    public refresh(): Promise<any> {
        return new Promise((resolve: any, reject: any) => {
            this.load().then((res) => {
                resolve(res);
            }).catch((error: any) => {
                reject(error);
            })
        })
    }

    /**
     * map对象
     *
     * @type {}
     * @memberof ${srfclassname('${ctrl.name}')}Base
     */   
    public map :any;

    /**
     * 图表div绑定的id
     *
     * @type {}
     * @memberof ${srfclassname('${ctrl.name}')}Base
     */   
    public mapId:string = this.$util.createUUID();

    /**
     * 数据
     *
     * @type {}
     * @memberof ${srfclassname('${ctrl.name}')}Base
     */   
    public dataList: any = []


    public mapStyle = "${ctrl.getMapStyle()}"

    public mapItems = [
    <#if ctrl.getPSSysMapItems?? && ctrl.getPSSysMapItems()??>
    <#list ctrl.getPSSysMapItems() as mapitem>
                        {
                            type:'${mapitem.getItemType()}',
                            bkcolor:'<#if mapitem.getBKColorPSAppDEField?? && mapitem.getBKColorPSAppDEField()??>${mapitem.getBKColorPSAppDEField().getCodeName()?lower_case}</#if>',
                            color:'<#if mapitem.getColorPSAppDEField?? && mapitem.getColorPSAppDEField()??>${mapitem.getColorPSAppDEField().getCodeName()?lower_case}</#if>',
                            content:'<#if mapitem.getContentPSDEField?? && mapitem.getContentPSDEField()??>${mapitem.getContentPSDEField().getCodeName()?lower_case}</#if>',
                            latitude:'<#if mapitem.getLatitudePSAppDEField?? && mapitem.getLatitudePSAppDEField()??>${mapitem.getLatitudePSAppDEField().getCodeName()?lower_case}</#if>',
                            longitude:'<#if mapitem.getLongitudePSAppDEField?? && mapitem.getLongitudePSAppDEField()??>${mapitem.getLongitudePSAppDEField().getCodeName()?lower_case}</#if>',
                            text:'<#if mapitem.getTextPSAppDEField?? && mapitem.getTextPSAppDEField()??>${mapitem.getTextPSAppDEField().getCodeName()?lower_case}</#if>',
                            tips:'<#if mapitem.getTipsPSAppDEField?? && mapitem.getTipsPSAppDEField()??>${mapitem.getTipsPSAppDEField().getCodeName()?lower_case}</#if>',
                        },
    </#list>
    </#if>
                    ]

    //点击弹出
    public tooltip = {
        formatter: (params: any, ticket: any, callback: any) => {
            return params.seriesName + '<br />' + params.name + '：' + (params.value ? params.value : 0)
        }
    }
    // 旁边的滑动栏
    public visualMap = {
        min: 0,
        max: 10,
        left: 'left',
        top: 'bottom',
        text: ['高', '低'],
        inRange: {
            color: ['#e0ffff', '#006edd']
        },
        show: true
    }

    //地图参数
    public geo = {
        map: 'china',
        roam: false,
        zoom: 1.23,
        label: {
            normal: {
                show: true,
                fontSize: '10',
                // 字体颜色
                color: 'rgba(0,0,0,0.7)',
            }
        },
        itemStyle: {
            normal: {
                // 边框颜色
                borderColor: 'rgba(0, 0, 0, 0.2)',
                // 地图默认背景
                areaColor: "#efefef",

            },
            emphasis: {
                // 点击背景颜色
                areaColor: '#F3B329',
                shadowOffsetX: 0,
                shadowOffsetY: 0,
                shadowBlur: 20,
                borderWidth: 0,
                shadowColor: 'rgba(0, 0, 0, 0.5)',
            }
        }
    }
    // 提示
    public series = [
        {
            name: '${ctrl.getName()}',
            type: 'map',
            geoIndex: 0,
            data: this.dataList
        }
    ]
    //option
    public option: any = {};

    /**
    * mounted
    */
    public mounted() {
        Object.assign(this.option, { tooltip: this.tooltip }, { visualMap: this.visualMap }, { geo: this.geo }, { series: this.series })
        let element: any = document.getElementById(this.mapId);
        this.map = echarts.init(element);
    }

    // 绘制
    public  setOptions(){
        if(!this.map){
            return
        }
        this.map.setOption(this.option);
    }
<#ibizinclude>
../@MACRO/CONTROL/CONTROL_BOTTOM-BASE.vue.ftl
</#ibizinclude>

<#ibizinclude>
../@MACRO/CONTROL/CONTROL-BASE.style.ftl
</#ibizinclude>